@@ -15,14 +15,13 @@ my(%source) =
 	1 =>
 	{
 		data     => undef,
-		expected => <<EOS,
-Undef Demo
-    |--- undef [VALUE 1]
-EOS
+		expected => 0,
 		literal => q|undef|,
 	},
 );
-my($renderer) = Data::RenderAsTree -> new
+my($count)		= 0;
+my($successes)	= 0;
+my($renderer)	= Data::RenderAsTree -> new
 	(
 		attributes       => 0,
 		max_key_length   => 25,
@@ -34,12 +33,24 @@ my($renderer) = Data::RenderAsTree -> new
 my($expected);
 my($got);
 my($i);
+my($result);
+my($x1, $x2);
 
 for $i (sort keys %source)
 {
-	$got      = $renderer -> run($source{$i}{data});
-	$expected = [split(/\n/, $source{$i}{expected})];
+	$count++;
 
-	print "$i: $source{$i}{literal}\n";
-	print Dumper($got);
+	$got      = $renderer -> run($source{$i}{data});
+	$expected = $source{$i}{expected} ? [split(/\n/, $source{$i}{expected})] : 0;
+	$x1			= Dumper($got);
+	$x2			= Dumper($expected);
+	$result		= $x1 eq $x2;
+
+	$successes++ if ($result);
+
+	print "$i: <$source{$i}{literal}>\n";
+	print "# $count: " . ($result ? "OK\n" : "Not OK\n");
 }
+
+print "Test count:    $count\n";
+print "Success count: $successes\n";
